Discover Packages
github.com/AlterNayte/go-retro
example
cats
package
Version:
v0.1.4
Opens a new window with list of versions in this module.
Published: Sep 3, 2024
License: MIT
Opens a new window with license information.
Imports: 1
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
Documentation
Documentation
¶
type CatFactsAPI struct {
Facts func() ([]Fact , error ) `method:"GET" path:"/facts"`
AnimalFacts func(animal_type string ) ([]Fact , error ) `method:"GET" path:"/facts" query:"animal_type"`
Fact func(id string ) (*Fact , error ) `method:"GET" path:"/facts/{id}"`
}
type Fact struct {
Id string `json:"_id"`
V int `json:"__v"`
Text string `json:"text"`
UpdatedAt time .Time `json:"updatedAt"`
Deleted bool `json:"deleted"`
Source string `json:"source"`
}
Source Files
¶
Click to show internal directories.
Click to hide internal directories.